@@ -5,17 +5,16 @@
 
 #include "gestures.h"
 
-#if 0
-#include <stdlib.h>
-#endif
 #include <math.h>
 
 #include "khotkeysglobal.h"
 
 #include "action_data/action_data.h"
 #include "input.h"
+
+#include <QApplication>
 #include <QDebug>
-#include <kapplication.h>
+
 #include <kkeyserver.h>
 #include <kxerrorhandler.h>
 
@@ -24,9 +23,6 @@
 // only necessary for circumventing bug #173606, see below
 #include <QX11Info>
 #include <X11/Xlib.h>
-//#include <fixx11h.h>
-
-// #include "voices.h"
 
 namespace KHotKeys
 {
@@ -39,6 +35,7 @@ Gesture::Gesture(bool enabled_P, QObject *parent_P)
     , button(0)
     , exclude(nullptr)
 {
+    Q_UNUSED(enabled_P);
     // qDebug() << enabled_P;
     nostroke_timer.setSingleShot(true);
     connect(&nostroke_timer, SIGNAL(timeout()), SLOT(stroke_timeout()));
@@ -82,13 +79,13 @@ void Gesture::update_grab()
     }
 
     if (_enabled && handlers.count() > 0 && (exclude == nullptr || !exclude->match(Window_data(windows_handler->active_window())))) {
-        kapp->removeNativeEventFilter(this); // avoid being installed twice
-        kapp->installNativeEventFilter(this);
+        qApp->removeNativeEventFilter(this); // avoid being installed twice
+        qApp->installNativeEventFilter(this);
         // CHECKME grab only when there's at least one gesture?
         grab_mouse(true);
     } else {
         grab_mouse(false);
-        kapp->removeNativeEventFilter(this);
+        qApp->removeNativeEventFilter(this);
     }
 }
 
@@ -269,6 +266,7 @@ void Gesture::grab_mouse(bool grab_P)
                         None,
                         None);
         bool err = handler.error(true);
+        Q_UNUSED(err);
         // qDebug() << "Gesture grab:" << err;
     } else {
         // qDebug() << "Gesture ungrab";
